package com.yanzhu.manage.mapper;

import java.util.List;
import com.yanzhu.manage.domain.AttendanceCfg;

/**
 * 考勤配置Mapper接口
 * 
 * @author yanzhu
 * @date 2024-10-08
 */
public interface AttendanceCfgMapper 
{
    /**
     * 查询考勤配置
     * 
     * @param id 考勤配置主键
     * @return 考勤配置
     */
    public AttendanceCfg selectAttendanceCfgById(Long id);

    /**
     * 查询考勤配置列表
     * 
     * @param attendanceCfg 考勤配置
     * @return 考勤配置集合
     */
    public List<AttendanceCfg> selectAttendanceCfgList(AttendanceCfg attendanceCfg);

    /**
     * 新增考勤配置
     * 
     * @param attendanceCfg 考勤配置
     * @return 结果
     */
    public int insertAttendanceCfg(AttendanceCfg attendanceCfg);

    /**
     * 修改考勤配置
     * 
     * @param attendanceCfg 考勤配置
     * @return 结果
     */
    public int updateAttendanceCfg(AttendanceCfg attendanceCfg);

    /**
     * 删除考勤配置
     * 
     * @param id 考勤配置主键
     * @return 结果
     */
    public int deleteAttendanceCfgById(Long id);

    /**
     * 批量删除考勤配置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAttendanceCfgByIds(Long[] ids);
}
